#! /usr/bin/env bash
#$EXTRACTRC `find . -name "*.ui"` >> rc.cpp || exit 11
$EXTRACTQML `find . -name "*.qml"` >> rc.cpp
$XGETTEXT *.cpp -o $podir/org.kde.telepathy-presence.pot
rm -f rc.cpp
